@@ -14,6 +14,8 @@ describe 'nova::api' do
 
     context 'with default parameters' do
 
+      it { is_expected.to contain_class('nova::keystone::authtoken') }
+
       it 'installs nova-api package and service' do
         is_expected.to contain_service('nova-api').with(
           :name      => platform_params[:nova_api_service],
@@ -36,13 +38,13 @@ describe 'nova::api' do
        is_expected.to contain_nova_config(
           'keystone_authtoken/auth_uri').with_value('http://127.0.0.1:5000/')
        is_expected.to contain_nova_config(
-          'keystone_authtoken/identity_uri').with_value('http://127.0.0.1:35357/')
+          'keystone_authtoken/auth_url').with_value('http://127.0.0.1:35357/')
         is_expected.to contain_nova_config(
-          'keystone_authtoken/admin_tenant_name').with_value('services')
+          'keystone_authtoken/project_name').with_value('services')
         is_expected.to contain_nova_config(
-          'keystone_authtoken/admin_user').with_value('nova')
+          'keystone_authtoken/username').with_value('nova')
         is_expected.to contain_nova_config(
-          'keystone_authtoken/admin_password').with_value('passw0rd').with_secret(true)
+          'keystone_authtoken/password').with_value('passw0rd').with_secret(true)
       end
 
       it 'enable metadata in evenlet configuration' do
@@ -65,9 +67,18 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('oslo_middleware/enable_proxy_headers_parsing').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/metadata_cache_expiration').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/vendordata_jsonfile_path').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/vendordata_providers').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/vendordata_dynamic_targets').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/vendordata_dynamic_connect_timeout').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/vendordata_dynamic_read_timeout').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/osapi_max_limit').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_link_prefix').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/osapi_glance_link_prefix').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/osapi_hide_server_address_states').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/allow_instance_snapshots').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/enable_network_quota').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/enable_instance_password').with('value' => '<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/password_length').with('value' => '<SERVICE DEFAULT>')
       end
 
       it 'unconfigures neutron_metadata proxy' do
@@ -100,9 +111,18 @@ describe 'nova::api' do
           :enable_proxy_headers_parsing         => true,
           :metadata_cache_expiration            => 15,
           :vendordata_jsonfile_path             => '/tmp',
+          :vendordata_providers                 => ['StaticJSON', 'DynamicJSON'],
+          :vendordata_dynamic_targets           => ['join@http://127.0.0.1:9999/v1/'],
+          :vendordata_dynamic_connect_timeout   => 30,
+          :vendordata_dynamic_read_timeout      => 30,
           :osapi_max_limit                      => 1000,
           :osapi_compute_link_prefix            => 'https://10.0.0.1:7777/',
           :osapi_glance_link_prefix             => 'https://10.0.0.1:6666/',
+          :osapi_hide_server_address_states     => 'building',
+          :allow_instance_snapshots             => true,
+          :enable_network_quota                 => false,
+          :enable_instance_password             => true,
+          :password_length                      => 12,
           :pci_alias                            => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\",\"name\":\"graphic_card\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"name\":\"network_card\"}]"
         })
       end
@@ -126,13 +146,13 @@ describe 'nova::api' do
         is_expected.to contain_nova_config(
           'keystone_authtoken/auth_uri').with_value('https://10.0.0.1:9999/')
         is_expected.to contain_nova_config(
-          'keystone_authtoken/identity_uri').with_value('https://10.0.0.1:8888/')
+          'keystone_authtoken/auth_url').with_value('https://10.0.0.1:8888/')
         is_expected.to contain_nova_config(
-          'keystone_authtoken/admin_tenant_name').with_value('service2')
+          'keystone_authtoken/project_name').with_value('service2')
         is_expected.to contain_nova_config(
-          'keystone_authtoken/admin_user').with_value('nova2')
+          'keystone_authtoken/username').with_value('nova2')
         is_expected.to contain_nova_config(
-          'keystone_authtoken/admin_password').with_value('passw0rd2').with_secret(true)
+          'keystone_authtoken/password').with_value('passw0rd2').with_secret(true)
         is_expected.to contain_nova_paste_api_ini(
           'filter:ratelimit/limits').with_value('(GET, "*", .*, 100, MINUTE);(POST, "*", .*, 200, MINUTE)')
       end
@@ -149,12 +169,21 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/default_floating_pool').with('value' => 'public')
         is_expected.to contain_nova_config('DEFAULT/metadata_cache_expiration').with('value' => '15')
         is_expected.to contain_nova_config('DEFAULT/vendordata_jsonfile_path').with('value' => '/tmp')
+        is_expected.to contain_nova_config('DEFAULT/vendordata_providers').with('value' => 'StaticJSON,DynamicJSON')
+        is_expected.to contain_nova_config('DEFAULT/vendordata_dynamic_targets').with('value' => 'join@http://127.0.0.1:9999/v1/')
+        is_expected.to contain_nova_config('DEFAULT/vendordata_dynamic_connect_timeout').with('value' => '30')
+        is_expected.to contain_nova_config('DEFAULT/vendordata_dynamic_read_timeout').with('value' => '30')
         is_expected.to contain_nova_config('DEFAULT/osapi_max_limit').with('value' => '1000')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_link_prefix').with('value' => 'https://10.0.0.1:7777/')
         is_expected.to contain_nova_config('DEFAULT/osapi_glance_link_prefix').with('value' => 'https://10.0.0.1:6666/')
         is_expected.to contain_nova_config('neutron/service_metadata_proxy').with('value' => true)
         is_expected.to contain_nova_config('neutron/metadata_proxy_shared_secret').with('value' => 'secrete')
         is_expected.to contain_nova_config('oslo_middleware/enable_proxy_headers_parsing').with('value' => true)
+        is_expected.to contain_nova_config('DEFAULT/osapi_hide_server_address_states').with('value' => 'building')
+        is_expected.to contain_nova_config('DEFAULT/allow_instance_snapshots').with('value' => true)
+        is_expected.to contain_nova_config('DEFAULT/enable_network_quota').with('value' => false)
+        is_expected.to contain_nova_config('DEFAULT/enable_instance_password').with('value' => true)
+        is_expected.to contain_nova_config('DEFAULT/password_length').with('value' => '12')
       end
 
       it 'configures nova pci_alias entries' do
@@ -175,7 +204,7 @@ describe 'nova::api' do
         :provider    => 'shell',
         :tries       => '10',
         :try_sleep   => '2',
-        :command     => 'nova --os-auth-url http://127.0.0.1:5000/ --os-tenant-name services --os-username nova --os-password passw0rd flavor-list',
+        :command     => 'nova --os-auth-url http://127.0.0.1:5000/ --os-project-name services --os-username nova --os-password passw0rd flavor-list',
       )}
 
       it { is_expected.to contain_anchor('create nova-api anchor').with(
@@ -256,30 +285,6 @@ describe 'nova::api' do
       end
     end
 
-    context 'with custom keystone identity_uri' do
-      before do
-        params.merge!({
-          :identity_uri => 'https://foo.bar:1234/',
-        })
-      end
-      it 'configures identity_uri' do
-        is_expected.to contain_nova_config('keystone_authtoken/identity_uri').with_value("https://foo.bar:1234/");
-      end
-    end
-
-    context 'with custom keystone identity_uri and auth_uri ' do
-      before do
-        params.merge!({
-          :identity_uri => 'https://foo.bar:35357/',
-          :auth_uri => 'https://foo.bar:5000/v2.0/',
-        })
-      end
-      it 'configures identity_uri' do
-        is_expected.to contain_nova_config('keystone_authtoken/identity_uri').with_value("https://foo.bar:35357/");
-        is_expected.to contain_nova_config('keystone_authtoken/auth_uri').with_value("https://foo.bar:5000/v2.0/");
-      end
-    end
-
     context 'when running nova API in wsgi compute, and enabling metadata' do
       before do
         params.merge!({ :service_name => 'httpd' })
