@@ -27,7 +27,12 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with(:value => 'false') }
       it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '<SERVICE DEFAULT>') }
       it { is_expected.to_not contain_nova_config('vnc/novncproxy_base_url') }
+      it { is_expected.to contain_nova_config('key_manager/api_class').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('barbican/barbican_api_version').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>') }
 
+      it { is_expected.to_not contain_package('cryptsetup').with( :ensure => 'present' )}
 
       it { is_expected.to_not contain_package('bridge-utils').with(
         :ensure => 'present',
@@ -68,6 +73,10 @@ describe 'nova::compute' do
           :pci_passthrough                    => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]",
           :config_drive_format                => 'vfat',
           :vcpu_pin_set                       => ['4-12','^8','15'],
+          :keymgr_api_class                   => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
+          :barbican_endpoint                  => 'http://localhost',
+          :barbican_api_version               => 'v1',
+          :barbican_auth_endpoint             => 'http://127.0.0.1:5000/v3',
         }
       end
 
@@ -91,6 +100,14 @@ describe 'nova::compute' do
         is_expected.to contain_nova_config('DEFAULT/compute_manager').with_value('ironic.nova.compute.manager.ClusteredComputeManager')
       end
 
+      it 'configures barbican service' do
+        is_expected.to contain_nova_config('key_manager/api_class').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
+        is_expected.to contain_nova_config('barbican/barbican_endpoint').with_value('http://localhost')
+        is_expected.to contain_nova_config('barbican/barbican_api_version').with_value('v1')
+        is_expected.to contain_nova_config('barbican/auth_endpoint').with_value('http://127.0.0.1:5000/v3')
+        is_expected.to contain_package('cryptsetup').with( :ensure => 'present' )
+      end
+
       it 'configures vnc in nova.conf' do
         is_expected.to contain_nova_config('vnc/enabled').with_value(true)
         is_expected.to contain_nova_config('vnc/vncserver_proxyclient_address').with_value('127.0.0.1')
@@ -125,6 +142,17 @@ describe 'nova::compute' do
       end
     end
 
+
+    context 'when vcpu_pin_set is empty' do
+      let :params do
+        { :vcpu_pin_set => "" }
+      end
+
+      it 'clears vcpu_pin_set configuration' do
+        is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '<SERVICE DEFAULT>')
+      end
+    end
+
     context 'with neutron_enabled set to false' do
       let :params do
         { :neutron_enabled => false }
